==> flutter_webview_desktop-0.0.12-dev.tar.gz: windows/webview_render.cc <==
#include "webview_bridge.h"
#include "include/wrapper/cef_helpers.h"
void WebviewClient::GetViewRect(CefRefPtr<CefBrowser> browser, CefRect &rect)
{
    CEF_REQUIRE_UI_THREAD();

    rect.Set(0, 0, texture_size_.width * texture_size_.devicePixelRatio, texture_size_.height * texture_size_.devicePixelRatio);
}
void WebviewClient::OnPaint(CefRefPtr<CefBrowser> browser,
                            PaintElementType type,
                            const RectList &dirtyRects,
                            const void *buffer,
                            int width,
                            int height)
{

    uint32_t stride = width * 4;
    size_t cb = stride * height;

    if (!pixel_buffer_ || pixel_buffer_->width != width ||
        pixel_buffer_->height != height)
    {
        if (!pixel_buffer_)
        {
            pixel_buffer_ = std::make_unique<FlutterDesktopPixelBuffer>();
            sw_buffer_ = std::shared_ptr<uint8_t>((uint8_t *)malloc(cb), free);
        }
        pixel_buffer_->width = width;
        pixel_buffer_->height = height;
        sw_buffer_.reset(new uint8_t[cb]);
        pixel_buffer_->buffer = sw_buffer_.get();
    }
    if (sw_buffer_ && buffer)
    {

        int32_t *dest = reinterpret_cast<int32_t *>(sw_buffer_.get());
        int32_t *src = (int32_t *)buffer;
        int32_t rgba;
        int32_t bgra;
        int length = width * height;
        for (int i = 0; i < length; i++)
        {
            bgra = src[i];
            // BGRA in hex = 0xAARRGGBB.
            rgba = (bgra & 0x00ff0000) >> 16    // Red >> Blue.
                   | (bgra & 0xff00ff00)        // Green Alpha.
                   | (bgra & 0x000000ff) << 16; // Blue >> Red.
            dest[i] = rgba;
        }
    }

    std::cout << "Test  OnPaint " << browser_->GetMainFrame()->GetURL() << std::endl;
    if (frame_available_ )
    {
        frame_available_();
    }
}

void WebviewClient::OnPopupShow(CefRefPtr<CefBrowser> browser, bool show)
{
    // ::MessageBox(NULL, L"OnPopupShow", L"Tip", MB_OK);
    // if (show)
    // {
    //     ::MessageBox(NULL, L"OnPopupShow is show ", L"Tip", MB_OK);
    // }
}

==> flutter_webview_desktop-0.0.23-dev.tar.gz: windows/webview_render.cc <==
#include "webview_bridge.h"
#include "include/wrapper/cef_helpers.h"
void WebviewClient::GetViewRect(CefRefPtr<CefBrowser> browser, CefRect &rect)
{
    CEF_REQUIRE_UI_THREAD();

    rect.Set(0, 0, texture_size_.width, texture_size_.height);
}
void WebviewClient::OnPaint(CefRefPtr<CefBrowser> browser,
                            PaintElementType type,
                            const RectList &dirtyRects,
                            const void *buffer,
                            int width,
                            int height)
{

    if (!browser_)
    {
        return;
    }
    uint32_t stride = width * 4;
    size_t cb = stride * height;

    if (!pixel_buffer_ || pixel_buffer_->width != width ||
        pixel_buffer_->height != height)
    {
        if (!pixel_buffer_)
        {
            pixel_buffer_ = std::make_unique<FlutterDesktopPixelBuffer>();
            sw_buffer_ = std::shared_ptr<uint8_t>((uint8_t *)malloc(cb), free);
        }
        pixel_buffer_->width = width;
        pixel_buffer_->height = height;
        sw_buffer_.reset(new uint8_t[cb]);
        pixel_buffer_->buffer = sw_buffer_.get();
    }
    if (sw_buffer_ && buffer)
    {

        int32_t *dest = reinterpret_cast<int32_t *>(sw_buffer_.get());
        int32_t *src = (int32_t *)buffer;
        int32_t rgba;
        int32_t bgra;
        int length = width * height;
        for (int i = 0; i < length; i++)
        {
            bgra = src[i];
            // BGRA in hex = 0xAARRGGBB.
            rgba = (bgra & 0x00ff0000) >> 16    // Red >> Blue.
                   | (bgra & 0xff00ff00)        // Green Alpha.
                   | (bgra & 0x000000ff) << 16; // Blue >> Red.
            dest[i] = rgba;
        }
    }

    //std::cout << "Test  OnPaint " << browser_->GetMainFrame()->GetURL() << std::endl;
    if (buffer && sw_buffer_ && frame_available_)
    {
        frame_available_();
    }
}

void WebviewClient::OnPopupShow(CefRefPtr<CefBrowser> browser, bool show)
{
    // ::MessageBox(NULL, L"OnPopupShow", L"Tip", MB_OK);
    // if (show)
    // {
    //     ::MessageBox(NULL, L"OnPopupShow is show ", L"Tip", MB_OK);
    // }
}

bool WebviewClient::GetScreenInfo(CefRefPtr<CefBrowser> browser,
                                  CefScreenInfo &screen_info)
{
    CEF_REQUIRE_UI_THREAD();
    // DCHECK_GT(device_scale_factor_, 0);

    // if (!::IsWindow(hwnd_))
    //     return false;

    CefRect view_rect;
    GetViewRect(browser, view_rect);

    screen_info.device_scale_factor = texture_size_.devicePixelRatio;

    // The screen info rectangles are used by the renderer to create and position
    // popups. Keep popups inside the view rectangle.
    screen_info.rect = view_rect;
    screen_info.available_rect = view_rect;
    return true;
}
